MethodChannelTaskProgress class

Default implementation of TaskProgressPlatformInterface using method channels.

Implemented types

Constructors

MethodChannelTaskProgress()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearProgress() → Future<void>
Clears the progress from native storage.
override
loadProgress() → Future<Map<String, int>>
Loads the progress from native storage.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveProgress({required int completed, required int total}) → Future<void>
Saves the progress to native storage.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited