TaskProgress class

Manages task progress with platform-specific persistence.

Constructors

TaskProgress([TaskProgressPlatformInterface? platform])
Creates a new TaskProgress instance.

Properties

currentProgress → TaskProgressIndicator
Gets the current progress.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearProgress() → Future<void>
Clears the progress from platform storage.
loadProgress() → Future<TaskProgressIndicator?>
Loads the progress from platform storage.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateProgress({required int completed, required int total}) → Future<void>
Updates the progress and saves it to platform storage.

Operators

operator ==(Object other) → bool
The equality operator.
inherited